"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4272 import (
        AbstractAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4273 import (
        AbstractShaftCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4274 import (
        AbstractShaftOrHousingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4275 import (
        AbstractShaftToMountableComponentConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4276 import (
        AGMAGleasonConicalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4277 import (
        AGMAGleasonConicalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4278 import (
        AGMAGleasonConicalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4279 import (
        AssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4280 import (
        BearingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4281 import (
        BeltConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4282 import (
        BeltDriveCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4283 import (
        BevelDifferentialGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4284 import (
        BevelDifferentialGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4285 import (
        BevelDifferentialGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4286 import (
        BevelDifferentialPlanetGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4287 import (
        BevelDifferentialSunGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4288 import (
        BevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4289 import (
        BevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4290 import (
        BevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4291 import (
        BoltCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4292 import (
        BoltedJointCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4293 import (
        ClutchCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4294 import (
        ClutchConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4295 import (
        ClutchHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4296 import (
        CoaxialConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4297 import (
        ComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4298 import (
        ConceptCouplingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4299 import (
        ConceptCouplingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4300 import (
        ConceptCouplingHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4301 import (
        ConceptGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4302 import (
        ConceptGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4303 import (
        ConceptGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4304 import (
        ConicalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4305 import (
        ConicalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4306 import (
        ConicalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4307 import (
        ConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4308 import (
        ConnectorCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4309 import (
        CouplingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4310 import (
        CouplingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4311 import (
        CouplingHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4312 import (
        CVTBeltConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4313 import (
        CVTCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4314 import (
        CVTPulleyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4315 import (
        CycloidalAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4316 import (
        CycloidalDiscCentralBearingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4317 import (
        CycloidalDiscCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4318 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4319 import (
        CylindricalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4320 import (
        CylindricalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4321 import (
        CylindricalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4322 import (
        CylindricalPlanetGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4323 import (
        DatumCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4324 import (
        ExternalCADModelCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4325 import (
        FaceGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4326 import (
        FaceGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4327 import (
        FaceGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4328 import (
        FEPartCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4329 import (
        FlexiblePinAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4330 import (
        GearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4331 import (
        GearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4332 import (
        GearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4333 import (
        GuideDxfModelCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4334 import (
        HypoidGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4335 import (
        HypoidGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4336 import (
        HypoidGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4337 import (
        InterMountableComponentConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4338 import (
        KlingelnbergCycloPalloidConicalGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4339 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4340 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4341 import (
        KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4342 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4343 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4344 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4345 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4346 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4347 import (
        MassDiscCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4348 import (
        MeasurementComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4349 import (
        MicrophoneArrayCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4350 import (
        MicrophoneCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4351 import (
        MountableComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4352 import (
        OilSealCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4353 import (
        PartCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4354 import (
        PartToPartShearCouplingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4355 import (
        PartToPartShearCouplingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4356 import (
        PartToPartShearCouplingHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4357 import (
        PlanetaryConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4358 import (
        PlanetaryGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4359 import (
        PlanetCarrierCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4360 import (
        PointLoadCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4361 import (
        PowerLoadCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4362 import (
        PulleyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4363 import (
        RingPinsCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4364 import (
        RingPinsToDiscConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4365 import (
        RollingRingAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4366 import (
        RollingRingCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4367 import (
        RollingRingConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4368 import (
        RootAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4369 import (
        ShaftCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4370 import (
        ShaftHubConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4371 import (
        ShaftToMountableComponentConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4372 import (
        SpecialisedAssemblyCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4373 import (
        SpiralBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4374 import (
        SpiralBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4375 import (
        SpiralBevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4376 import (
        SpringDamperCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4377 import (
        SpringDamperConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4378 import (
        SpringDamperHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4379 import (
        StraightBevelDiffGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4380 import (
        StraightBevelDiffGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4381 import (
        StraightBevelDiffGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4382 import (
        StraightBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4383 import (
        StraightBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4384 import (
        StraightBevelGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4385 import (
        StraightBevelPlanetGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4386 import (
        StraightBevelSunGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4387 import (
        SynchroniserCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4388 import (
        SynchroniserHalfCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4389 import (
        SynchroniserPartCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4390 import (
        SynchroniserSleeveCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4391 import (
        TorqueConverterCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4392 import (
        TorqueConverterConnectionCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4393 import (
        TorqueConverterPumpCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4394 import (
        TorqueConverterTurbineCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4395 import (
        UnbalancedMassCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4396 import (
        VirtualComponentCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4397 import (
        WormGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4398 import (
        WormGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4399 import (
        WormGearSetCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4400 import (
        ZerolBevelGearCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4401 import (
        ZerolBevelGearMeshCompoundPowerFlow,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows.compound._4402 import (
        ZerolBevelGearSetCompoundPowerFlow,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.power_flows.compound._4272": [
            "AbstractAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4273": [
            "AbstractShaftCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4274": [
            "AbstractShaftOrHousingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4275": [
            "AbstractShaftToMountableComponentConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4276": [
            "AGMAGleasonConicalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4277": [
            "AGMAGleasonConicalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4278": [
            "AGMAGleasonConicalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4279": [
            "AssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4280": [
            "BearingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4281": [
            "BeltConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4282": [
            "BeltDriveCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4283": [
            "BevelDifferentialGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4284": [
            "BevelDifferentialGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4285": [
            "BevelDifferentialGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4286": [
            "BevelDifferentialPlanetGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4287": [
            "BevelDifferentialSunGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4288": [
            "BevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4289": [
            "BevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4290": [
            "BevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4291": [
            "BoltCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4292": [
            "BoltedJointCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4293": [
            "ClutchCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4294": [
            "ClutchConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4295": [
            "ClutchHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4296": [
            "CoaxialConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4297": [
            "ComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4298": [
            "ConceptCouplingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4299": [
            "ConceptCouplingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4300": [
            "ConceptCouplingHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4301": [
            "ConceptGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4302": [
            "ConceptGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4303": [
            "ConceptGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4304": [
            "ConicalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4305": [
            "ConicalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4306": [
            "ConicalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4307": [
            "ConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4308": [
            "ConnectorCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4309": [
            "CouplingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4310": [
            "CouplingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4311": [
            "CouplingHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4312": [
            "CVTBeltConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4313": [
            "CVTCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4314": [
            "CVTPulleyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4315": [
            "CycloidalAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4316": [
            "CycloidalDiscCentralBearingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4317": [
            "CycloidalDiscCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4318": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4319": [
            "CylindricalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4320": [
            "CylindricalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4321": [
            "CylindricalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4322": [
            "CylindricalPlanetGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4323": [
            "DatumCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4324": [
            "ExternalCADModelCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4325": [
            "FaceGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4326": [
            "FaceGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4327": [
            "FaceGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4328": [
            "FEPartCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4329": [
            "FlexiblePinAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4330": [
            "GearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4331": [
            "GearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4332": [
            "GearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4333": [
            "GuideDxfModelCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4334": [
            "HypoidGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4335": [
            "HypoidGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4336": [
            "HypoidGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4337": [
            "InterMountableComponentConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4338": [
            "KlingelnbergCycloPalloidConicalGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4339": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4340": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4341": [
            "KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4342": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4343": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4344": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4345": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4346": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4347": [
            "MassDiscCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4348": [
            "MeasurementComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4349": [
            "MicrophoneArrayCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4350": [
            "MicrophoneCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4351": [
            "MountableComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4352": [
            "OilSealCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4353": [
            "PartCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4354": [
            "PartToPartShearCouplingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4355": [
            "PartToPartShearCouplingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4356": [
            "PartToPartShearCouplingHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4357": [
            "PlanetaryConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4358": [
            "PlanetaryGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4359": [
            "PlanetCarrierCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4360": [
            "PointLoadCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4361": [
            "PowerLoadCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4362": [
            "PulleyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4363": [
            "RingPinsCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4364": [
            "RingPinsToDiscConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4365": [
            "RollingRingAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4366": [
            "RollingRingCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4367": [
            "RollingRingConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4368": [
            "RootAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4369": [
            "ShaftCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4370": [
            "ShaftHubConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4371": [
            "ShaftToMountableComponentConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4372": [
            "SpecialisedAssemblyCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4373": [
            "SpiralBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4374": [
            "SpiralBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4375": [
            "SpiralBevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4376": [
            "SpringDamperCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4377": [
            "SpringDamperConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4378": [
            "SpringDamperHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4379": [
            "StraightBevelDiffGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4380": [
            "StraightBevelDiffGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4381": [
            "StraightBevelDiffGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4382": [
            "StraightBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4383": [
            "StraightBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4384": [
            "StraightBevelGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4385": [
            "StraightBevelPlanetGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4386": [
            "StraightBevelSunGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4387": [
            "SynchroniserCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4388": [
            "SynchroniserHalfCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4389": [
            "SynchroniserPartCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4390": [
            "SynchroniserSleeveCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4391": [
            "TorqueConverterCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4392": [
            "TorqueConverterConnectionCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4393": [
            "TorqueConverterPumpCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4394": [
            "TorqueConverterTurbineCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4395": [
            "UnbalancedMassCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4396": [
            "VirtualComponentCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4397": [
            "WormGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4398": [
            "WormGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4399": [
            "WormGearSetCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4400": [
            "ZerolBevelGearCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4401": [
            "ZerolBevelGearMeshCompoundPowerFlow"
        ],
        "_private.system_model.analyses_and_results.power_flows.compound._4402": [
            "ZerolBevelGearSetCompoundPowerFlow"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundPowerFlow",
    "AbstractShaftCompoundPowerFlow",
    "AbstractShaftOrHousingCompoundPowerFlow",
    "AbstractShaftToMountableComponentConnectionCompoundPowerFlow",
    "AGMAGleasonConicalGearCompoundPowerFlow",
    "AGMAGleasonConicalGearMeshCompoundPowerFlow",
    "AGMAGleasonConicalGearSetCompoundPowerFlow",
    "AssemblyCompoundPowerFlow",
    "BearingCompoundPowerFlow",
    "BeltConnectionCompoundPowerFlow",
    "BeltDriveCompoundPowerFlow",
    "BevelDifferentialGearCompoundPowerFlow",
    "BevelDifferentialGearMeshCompoundPowerFlow",
    "BevelDifferentialGearSetCompoundPowerFlow",
    "BevelDifferentialPlanetGearCompoundPowerFlow",
    "BevelDifferentialSunGearCompoundPowerFlow",
    "BevelGearCompoundPowerFlow",
    "BevelGearMeshCompoundPowerFlow",
    "BevelGearSetCompoundPowerFlow",
    "BoltCompoundPowerFlow",
    "BoltedJointCompoundPowerFlow",
    "ClutchCompoundPowerFlow",
    "ClutchConnectionCompoundPowerFlow",
    "ClutchHalfCompoundPowerFlow",
    "CoaxialConnectionCompoundPowerFlow",
    "ComponentCompoundPowerFlow",
    "ConceptCouplingCompoundPowerFlow",
    "ConceptCouplingConnectionCompoundPowerFlow",
    "ConceptCouplingHalfCompoundPowerFlow",
    "ConceptGearCompoundPowerFlow",
    "ConceptGearMeshCompoundPowerFlow",
    "ConceptGearSetCompoundPowerFlow",
    "ConicalGearCompoundPowerFlow",
    "ConicalGearMeshCompoundPowerFlow",
    "ConicalGearSetCompoundPowerFlow",
    "ConnectionCompoundPowerFlow",
    "ConnectorCompoundPowerFlow",
    "CouplingCompoundPowerFlow",
    "CouplingConnectionCompoundPowerFlow",
    "CouplingHalfCompoundPowerFlow",
    "CVTBeltConnectionCompoundPowerFlow",
    "CVTCompoundPowerFlow",
    "CVTPulleyCompoundPowerFlow",
    "CycloidalAssemblyCompoundPowerFlow",
    "CycloidalDiscCentralBearingConnectionCompoundPowerFlow",
    "CycloidalDiscCompoundPowerFlow",
    "CycloidalDiscPlanetaryBearingConnectionCompoundPowerFlow",
    "CylindricalGearCompoundPowerFlow",
    "CylindricalGearMeshCompoundPowerFlow",
    "CylindricalGearSetCompoundPowerFlow",
    "CylindricalPlanetGearCompoundPowerFlow",
    "DatumCompoundPowerFlow",
    "ExternalCADModelCompoundPowerFlow",
    "FaceGearCompoundPowerFlow",
    "FaceGearMeshCompoundPowerFlow",
    "FaceGearSetCompoundPowerFlow",
    "FEPartCompoundPowerFlow",
    "FlexiblePinAssemblyCompoundPowerFlow",
    "GearCompoundPowerFlow",
    "GearMeshCompoundPowerFlow",
    "GearSetCompoundPowerFlow",
    "GuideDxfModelCompoundPowerFlow",
    "HypoidGearCompoundPowerFlow",
    "HypoidGearMeshCompoundPowerFlow",
    "HypoidGearSetCompoundPowerFlow",
    "InterMountableComponentConnectionCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidConicalGearSetCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundPowerFlow",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundPowerFlow",
    "MassDiscCompoundPowerFlow",
    "MeasurementComponentCompoundPowerFlow",
    "MicrophoneArrayCompoundPowerFlow",
    "MicrophoneCompoundPowerFlow",
    "MountableComponentCompoundPowerFlow",
    "OilSealCompoundPowerFlow",
    "PartCompoundPowerFlow",
    "PartToPartShearCouplingCompoundPowerFlow",
    "PartToPartShearCouplingConnectionCompoundPowerFlow",
    "PartToPartShearCouplingHalfCompoundPowerFlow",
    "PlanetaryConnectionCompoundPowerFlow",
    "PlanetaryGearSetCompoundPowerFlow",
    "PlanetCarrierCompoundPowerFlow",
    "PointLoadCompoundPowerFlow",
    "PowerLoadCompoundPowerFlow",
    "PulleyCompoundPowerFlow",
    "RingPinsCompoundPowerFlow",
    "RingPinsToDiscConnectionCompoundPowerFlow",
    "RollingRingAssemblyCompoundPowerFlow",
    "RollingRingCompoundPowerFlow",
    "RollingRingConnectionCompoundPowerFlow",
    "RootAssemblyCompoundPowerFlow",
    "ShaftCompoundPowerFlow",
    "ShaftHubConnectionCompoundPowerFlow",
    "ShaftToMountableComponentConnectionCompoundPowerFlow",
    "SpecialisedAssemblyCompoundPowerFlow",
    "SpiralBevelGearCompoundPowerFlow",
    "SpiralBevelGearMeshCompoundPowerFlow",
    "SpiralBevelGearSetCompoundPowerFlow",
    "SpringDamperCompoundPowerFlow",
    "SpringDamperConnectionCompoundPowerFlow",
    "SpringDamperHalfCompoundPowerFlow",
    "StraightBevelDiffGearCompoundPowerFlow",
    "StraightBevelDiffGearMeshCompoundPowerFlow",
    "StraightBevelDiffGearSetCompoundPowerFlow",
    "StraightBevelGearCompoundPowerFlow",
    "StraightBevelGearMeshCompoundPowerFlow",
    "StraightBevelGearSetCompoundPowerFlow",
    "StraightBevelPlanetGearCompoundPowerFlow",
    "StraightBevelSunGearCompoundPowerFlow",
    "SynchroniserCompoundPowerFlow",
    "SynchroniserHalfCompoundPowerFlow",
    "SynchroniserPartCompoundPowerFlow",
    "SynchroniserSleeveCompoundPowerFlow",
    "TorqueConverterCompoundPowerFlow",
    "TorqueConverterConnectionCompoundPowerFlow",
    "TorqueConverterPumpCompoundPowerFlow",
    "TorqueConverterTurbineCompoundPowerFlow",
    "UnbalancedMassCompoundPowerFlow",
    "VirtualComponentCompoundPowerFlow",
    "WormGearCompoundPowerFlow",
    "WormGearMeshCompoundPowerFlow",
    "WormGearSetCompoundPowerFlow",
    "ZerolBevelGearCompoundPowerFlow",
    "ZerolBevelGearMeshCompoundPowerFlow",
    "ZerolBevelGearSetCompoundPowerFlow",
)



"""ConnectionCompoundAdvancedSystemDeflection"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.analysis_cases import _7704
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CONNECTION_COMPOUND_ADVANCED_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections.Compound",
    "ConnectionCompoundAdvancedSystemDeflection",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
        _7460,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
        _7563,
        _7565,
        _7569,
        _7572,
        _7577,
        _7582,
        _7584,
        _7587,
        _7590,
        _7593,
        _7598,
        _7600,
        _7604,
        _7606,
        _7608,
        _7614,
        _7619,
        _7623,
        _7625,
        _7627,
        _7630,
        _7633,
        _7643,
        _7645,
        _7652,
        _7655,
        _7659,
        _7662,
        _7665,
        _7668,
        _7671,
        _7680,
        _7686,
        _7689,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import _7708
    from mastapy._private.system_model.analyses_and_results import _2734

    Self = TypeVar("Self", bound="ConnectionCompoundAdvancedSystemDeflection")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConnectionCompoundAdvancedSystemDeflection._Cast_ConnectionCompoundAdvancedSystemDeflection",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConnectionCompoundAdvancedSystemDeflection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConnectionCompoundAdvancedSystemDeflection:
    """Special nested class for casting ConnectionCompoundAdvancedSystemDeflection to subclasses."""

    __parent__: "ConnectionCompoundAdvancedSystemDeflection"

    @property
    def connection_compound_analysis(
        self: "CastSelf",
    ) -> "_7704.ConnectionCompoundAnalysis":
        return self.__parent__._cast(_7704.ConnectionCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7708.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7708,
        )

        return self.__parent__._cast(_7708.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def abstract_shaft_to_mountable_component_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7563.AbstractShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7563,
        )

        return self.__parent__._cast(
            _7563.AbstractShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def agma_gleason_conical_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7565.AGMAGleasonConicalGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7565,
        )

        return self.__parent__._cast(
            _7565.AGMAGleasonConicalGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def belt_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7569.BeltConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7569,
        )

        return self.__parent__._cast(
            _7569.BeltConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def bevel_differential_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7572.BevelDifferentialGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7572,
        )

        return self.__parent__._cast(
            _7572.BevelDifferentialGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def bevel_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7577.BevelGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7577,
        )

        return self.__parent__._cast(
            _7577.BevelGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def clutch_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7582.ClutchConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7582,
        )

        return self.__parent__._cast(
            _7582.ClutchConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def coaxial_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7584.CoaxialConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7584,
        )

        return self.__parent__._cast(
            _7584.CoaxialConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def concept_coupling_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7587.ConceptCouplingConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7587,
        )

        return self.__parent__._cast(
            _7587.ConceptCouplingConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def concept_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7590.ConceptGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7590,
        )

        return self.__parent__._cast(
            _7590.ConceptGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def conical_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7593.ConicalGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7593,
        )

        return self.__parent__._cast(
            _7593.ConicalGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def coupling_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7598.CouplingConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7598,
        )

        return self.__parent__._cast(
            _7598.CouplingConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def cvt_belt_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7600.CVTBeltConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7600,
        )

        return self.__parent__._cast(
            _7600.CVTBeltConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def cycloidal_disc_central_bearing_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7604.CycloidalDiscCentralBearingConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7604,
        )

        return self.__parent__._cast(
            _7604.CycloidalDiscCentralBearingConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def cycloidal_disc_planetary_bearing_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> (
        "_7606.CycloidalDiscPlanetaryBearingConnectionCompoundAdvancedSystemDeflection"
    ):
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7606,
        )

        return self.__parent__._cast(
            _7606.CycloidalDiscPlanetaryBearingConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def cylindrical_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7608.CylindricalGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7608,
        )

        return self.__parent__._cast(
            _7608.CylindricalGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def face_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7614.FaceGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7614,
        )

        return self.__parent__._cast(_7614.FaceGearMeshCompoundAdvancedSystemDeflection)

    @property
    def gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7619.GearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7619,
        )

        return self.__parent__._cast(_7619.GearMeshCompoundAdvancedSystemDeflection)

    @property
    def hypoid_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7623.HypoidGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7623,
        )

        return self.__parent__._cast(
            _7623.HypoidGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def inter_mountable_component_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7625.InterMountableComponentConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7625,
        )

        return self.__parent__._cast(
            _7625.InterMountableComponentConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> (
        "_7627.KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedSystemDeflection"
    ):
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7627,
        )

        return self.__parent__._cast(
            _7627.KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7630.KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7630,
        )

        return self.__parent__._cast(
            _7630.KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7633.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7633,
        )

        return self.__parent__._cast(
            _7633.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def part_to_part_shear_coupling_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7643.PartToPartShearCouplingConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7643,
        )

        return self.__parent__._cast(
            _7643.PartToPartShearCouplingConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def planetary_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7645.PlanetaryConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7645,
        )

        return self.__parent__._cast(
            _7645.PlanetaryConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def ring_pins_to_disc_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7652.RingPinsToDiscConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7652,
        )

        return self.__parent__._cast(
            _7652.RingPinsToDiscConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def rolling_ring_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7655.RollingRingConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7655,
        )

        return self.__parent__._cast(
            _7655.RollingRingConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def shaft_to_mountable_component_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7659.ShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7659,
        )

        return self.__parent__._cast(
            _7659.ShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def spiral_bevel_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7662.SpiralBevelGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7662,
        )

        return self.__parent__._cast(
            _7662.SpiralBevelGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def spring_damper_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7665.SpringDamperConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7665,
        )

        return self.__parent__._cast(
            _7665.SpringDamperConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def straight_bevel_diff_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7668.StraightBevelDiffGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7668,
        )

        return self.__parent__._cast(
            _7668.StraightBevelDiffGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def straight_bevel_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7671.StraightBevelGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7671,
        )

        return self.__parent__._cast(
            _7671.StraightBevelGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def torque_converter_connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7680.TorqueConverterConnectionCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7680,
        )

        return self.__parent__._cast(
            _7680.TorqueConverterConnectionCompoundAdvancedSystemDeflection
        )

    @property
    def worm_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7686.WormGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7686,
        )

        return self.__parent__._cast(_7686.WormGearMeshCompoundAdvancedSystemDeflection)

    @property
    def zerol_bevel_gear_mesh_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7689.ZerolBevelGearMeshCompoundAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound import (
            _7689,
        )

        return self.__parent__._cast(
            _7689.ZerolBevelGearMeshCompoundAdvancedSystemDeflection
        )

    @property
    def connection_compound_advanced_system_deflection(
        self: "CastSelf",
    ) -> "ConnectionCompoundAdvancedSystemDeflection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConnectionCompoundAdvancedSystemDeflection(_7704.ConnectionCompoundAnalysis):
    """ConnectionCompoundAdvancedSystemDeflection

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONNECTION_COMPOUND_ADVANCED_SYSTEM_DEFLECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def connection_analysis_cases(
        self: "Self",
    ) -> "List[_7460.ConnectionAdvancedSystemDeflection]":
        """List[mastapy._private.system_model.analyses_and_results.advanced_system_deflections.ConnectionAdvancedSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def connection_analysis_cases_ready(
        self: "Self",
    ) -> "List[_7460.ConnectionAdvancedSystemDeflection]":
        """List[mastapy._private.system_model.analyses_and_results.advanced_system_deflections.ConnectionAdvancedSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_ConnectionCompoundAdvancedSystemDeflection":
        """Cast to another type.

        Returns:
            _Cast_ConnectionCompoundAdvancedSystemDeflection
        """
        return _Cast_ConnectionCompoundAdvancedSystemDeflection(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.materials.efficiency._303 import BearingEfficiencyRatingMethod
    from mastapy._private.materials.efficiency._304 import CombinedResistiveTorque
    from mastapy._private.materials.efficiency._305 import IndependentPowerLoss
    from mastapy._private.materials.efficiency._306 import IndependentResistiveTorque
    from mastapy._private.materials.efficiency._307 import LoadAndSpeedCombinedPowerLoss
    from mastapy._private.materials.efficiency._308 import OilPumpDetail
    from mastapy._private.materials.efficiency._309 import OilPumpDriveType
    from mastapy._private.materials.efficiency._310 import OilSealLossCalculationMethod
    from mastapy._private.materials.efficiency._311 import OilSealMaterialType
    from mastapy._private.materials.efficiency._312 import PowerLoss
    from mastapy._private.materials.efficiency._313 import ResistiveTorque
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.materials.efficiency._303": ["BearingEfficiencyRatingMethod"],
        "_private.materials.efficiency._304": ["CombinedResistiveTorque"],
        "_private.materials.efficiency._305": ["IndependentPowerLoss"],
        "_private.materials.efficiency._306": ["IndependentResistiveTorque"],
        "_private.materials.efficiency._307": ["LoadAndSpeedCombinedPowerLoss"],
        "_private.materials.efficiency._308": ["OilPumpDetail"],
        "_private.materials.efficiency._309": ["OilPumpDriveType"],
        "_private.materials.efficiency._310": ["OilSealLossCalculationMethod"],
        "_private.materials.efficiency._311": ["OilSealMaterialType"],
        "_private.materials.efficiency._312": ["PowerLoss"],
        "_private.materials.efficiency._313": ["ResistiveTorque"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BearingEfficiencyRatingMethod",
    "CombinedResistiveTorque",
    "IndependentPowerLoss",
    "IndependentResistiveTorque",
    "LoadAndSpeedCombinedPowerLoss",
    "OilPumpDetail",
    "OilPumpDriveType",
    "OilSealLossCalculationMethod",
    "OilSealMaterialType",
    "PowerLoss",
    "ResistiveTorque",
)



"""ConcentricOrParallelPartGroup"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.system_model.part_model.part_groups import _2548
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_CONCENTRIC_OR_PARALLEL_PART_GROUP = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel.PartGroups", "ConcentricOrParallelPartGroup"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.part_model.part_groups import _2543, _2546, _2547

    Self = TypeVar("Self", bound="ConcentricOrParallelPartGroup")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConcentricOrParallelPartGroup._Cast_ConcentricOrParallelPartGroup",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConcentricOrParallelPartGroup",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConcentricOrParallelPartGroup:
    """Special nested class for casting ConcentricOrParallelPartGroup to subclasses."""

    __parent__: "ConcentricOrParallelPartGroup"

    @property
    def part_group(self: "CastSelf") -> "_2548.PartGroup":
        return self.__parent__._cast(_2548.PartGroup)

    @property
    def concentric_part_group(self: "CastSelf") -> "_2543.ConcentricPartGroup":
        from mastapy._private.system_model.part_model.part_groups import _2543

        return self.__parent__._cast(_2543.ConcentricPartGroup)

    @property
    def parallel_part_group(self: "CastSelf") -> "_2546.ParallelPartGroup":
        from mastapy._private.system_model.part_model.part_groups import _2546

        return self.__parent__._cast(_2546.ParallelPartGroup)

    @property
    def parallel_part_group_selection(
        self: "CastSelf",
    ) -> "_2547.ParallelPartGroupSelection":
        from mastapy._private.system_model.part_model.part_groups import _2547

        return self.__parent__._cast(_2547.ParallelPartGroupSelection)

    @property
    def concentric_or_parallel_part_group(
        self: "CastSelf",
    ) -> "ConcentricOrParallelPartGroup":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConcentricOrParallelPartGroup(_2548.PartGroup):
    """ConcentricOrParallelPartGroup

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONCENTRIC_OR_PARALLEL_PART_GROUP

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_ConcentricOrParallelPartGroup":
        """Cast to another type.

        Returns:
            _Cast_ConcentricOrParallelPartGroup
        """
        return _Cast_ConcentricOrParallelPartGroup(self)



"""CouplingConnectionCompoundParametricStudyTool"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
    _4617,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_COUPLING_CONNECTION_COMPOUND_PARAMETRIC_STUDY_TOOL = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools.Compound",
    "CouplingConnectionCompoundParametricStudyTool",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
        _4440,
    )
    from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
        _4574,
        _4579,
        _4635,
        _4657,
        _4672,
        _4587,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7704,
        _7708,
    )
    from mastapy._private.system_model.analyses_and_results import _2734

    Self = TypeVar("Self", bound="CouplingConnectionCompoundParametricStudyTool")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CouplingConnectionCompoundParametricStudyTool._Cast_CouplingConnectionCompoundParametricStudyTool",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CouplingConnectionCompoundParametricStudyTool",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CouplingConnectionCompoundParametricStudyTool:
    """Special nested class for casting CouplingConnectionCompoundParametricStudyTool to subclasses."""

    __parent__: "CouplingConnectionCompoundParametricStudyTool"

    @property
    def inter_mountable_component_connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4617.InterMountableComponentConnectionCompoundParametricStudyTool":
        return self.__parent__._cast(
            _4617.InterMountableComponentConnectionCompoundParametricStudyTool
        )

    @property
    def connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4587.ConnectionCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4587,
        )

        return self.__parent__._cast(_4587.ConnectionCompoundParametricStudyTool)

    @property
    def connection_compound_analysis(
        self: "CastSelf",
    ) -> "_7704.ConnectionCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7704,
        )

        return self.__parent__._cast(_7704.ConnectionCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7708.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7708,
        )

        return self.__parent__._cast(_7708.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def clutch_connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4574.ClutchConnectionCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4574,
        )

        return self.__parent__._cast(_4574.ClutchConnectionCompoundParametricStudyTool)

    @property
    def concept_coupling_connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4579.ConceptCouplingConnectionCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4579,
        )

        return self.__parent__._cast(
            _4579.ConceptCouplingConnectionCompoundParametricStudyTool
        )

    @property
    def part_to_part_shear_coupling_connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4635.PartToPartShearCouplingConnectionCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4635,
        )

        return self.__parent__._cast(
            _4635.PartToPartShearCouplingConnectionCompoundParametricStudyTool
        )

    @property
    def spring_damper_connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4657.SpringDamperConnectionCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4657,
        )

        return self.__parent__._cast(
            _4657.SpringDamperConnectionCompoundParametricStudyTool
        )

    @property
    def torque_converter_connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4672.TorqueConverterConnectionCompoundParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools.compound import (
            _4672,
        )

        return self.__parent__._cast(
            _4672.TorqueConverterConnectionCompoundParametricStudyTool
        )

    @property
    def coupling_connection_compound_parametric_study_tool(
        self: "CastSelf",
    ) -> "CouplingConnectionCompoundParametricStudyTool":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CouplingConnectionCompoundParametricStudyTool(
    _4617.InterMountableComponentConnectionCompoundParametricStudyTool
):
    """CouplingConnectionCompoundParametricStudyTool

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _COUPLING_CONNECTION_COMPOUND_PARAMETRIC_STUDY_TOOL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def connection_analysis_cases(
        self: "Self",
    ) -> "List[_4440.CouplingConnectionParametricStudyTool]":
        """List[mastapy._private.system_model.analyses_and_results.parametric_study_tools.CouplingConnectionParametricStudyTool]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def connection_analysis_cases_ready(
        self: "Self",
    ) -> "List[_4440.CouplingConnectionParametricStudyTool]":
        """List[mastapy._private.system_model.analyses_and_results.parametric_study_tools.CouplingConnectionParametricStudyTool]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_CouplingConnectionCompoundParametricStudyTool":
        """Cast to another type.

        Returns:
            _Cast_CouplingConnectionCompoundParametricStudyTool
        """
        return _Cast_CouplingConnectionCompoundParametricStudyTool(self)



"""ConicalManufacturingSMTControlParameters"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import utility
from mastapy._private.gears.manufacturing.bevel.control_parameters import _840
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CONICAL_MANUFACTURING_SMT_CONTROL_PARAMETERS = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Bevel.ControlParameters",
    "ConicalManufacturingSMTControlParameters",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ConicalManufacturingSMTControlParameters")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConicalManufacturingSMTControlParameters._Cast_ConicalManufacturingSMTControlParameters",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConicalManufacturingSMTControlParameters",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalManufacturingSMTControlParameters:
    """Special nested class for casting ConicalManufacturingSMTControlParameters to subclasses."""

    __parent__: "ConicalManufacturingSMTControlParameters"

    @property
    def conical_gear_manufacturing_control_parameters(
        self: "CastSelf",
    ) -> "_840.ConicalGearManufacturingControlParameters":
        return self.__parent__._cast(_840.ConicalGearManufacturingControlParameters)

    @property
    def conical_manufacturing_smt_control_parameters(
        self: "CastSelf",
    ) -> "ConicalManufacturingSMTControlParameters":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConicalManufacturingSMTControlParameters(
    _840.ConicalGearManufacturingControlParameters
):
    """ConicalManufacturingSMTControlParameters

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONICAL_MANUFACTURING_SMT_CONTROL_PARAMETERS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def angular_acceleration(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.AngularAcceleration

        if temp is None:
            return 0.0

        return temp

    @angular_acceleration.setter
    @enforce_parameter_types
    def angular_acceleration(self: "Self", value: "float") -> None:
        self.wrapped.AngularAcceleration = float(value) if value is not None else 0.0

    @property
    def clearance_between_finish_root_and_rough_root(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ClearanceBetweenFinishRootAndRoughRoot

        if temp is None:
            return 0.0

        return temp

    @clearance_between_finish_root_and_rough_root.setter
    @enforce_parameter_types
    def clearance_between_finish_root_and_rough_root(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.ClearanceBetweenFinishRootAndRoughRoot = (
            float(value) if value is not None else 0.0
        )

    @property
    def delta_e(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.DeltaE

        if temp is None:
            return 0.0

        return temp

    @delta_e.setter
    @enforce_parameter_types
    def delta_e(self: "Self", value: "float") -> None:
        self.wrapped.DeltaE = float(value) if value is not None else 0.0

    @property
    def delta_sigma(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.DeltaSigma

        if temp is None:
            return 0.0

        return temp

    @delta_sigma.setter
    @enforce_parameter_types
    def delta_sigma(self: "Self", value: "float") -> None:
        self.wrapped.DeltaSigma = float(value) if value is not None else 0.0

    @property
    def delta_xp(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.DeltaXP

        if temp is None:
            return 0.0

        return temp

    @delta_xp.setter
    @enforce_parameter_types
    def delta_xp(self: "Self", value: "float") -> None:
        self.wrapped.DeltaXP = float(value) if value is not None else 0.0

    @property
    def delta_xw(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.DeltaXW

        if temp is None:
            return 0.0

        return temp

    @delta_xw.setter
    @enforce_parameter_types
    def delta_xw(self: "Self", value: "float") -> None:
        self.wrapped.DeltaXW = float(value) if value is not None else 0.0

    @property
    def direction_angle_of_poc(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.DirectionAngleOfPOC

        if temp is None:
            return 0.0

        return temp

    @direction_angle_of_poc.setter
    @enforce_parameter_types
    def direction_angle_of_poc(self: "Self", value: "float") -> None:
        self.wrapped.DirectionAngleOfPOC = float(value) if value is not None else 0.0

    @property
    def initial_workhead_offset(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.InitialWorkheadOffset

        if temp is None:
            return 0.0

        return temp

    @initial_workhead_offset.setter
    @enforce_parameter_types
    def initial_workhead_offset(self: "Self", value: "float") -> None:
        self.wrapped.InitialWorkheadOffset = float(value) if value is not None else 0.0

    @property
    def mean_contact_point_h(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MeanContactPointH

        if temp is None:
            return 0.0

        return temp

    @mean_contact_point_h.setter
    @enforce_parameter_types
    def mean_contact_point_h(self: "Self", value: "float") -> None:
        self.wrapped.MeanContactPointH = float(value) if value is not None else 0.0

    @property
    def mean_contact_point_v(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MeanContactPointV

        if temp is None:
            return 0.0

        return temp

    @mean_contact_point_v.setter
    @enforce_parameter_types
    def mean_contact_point_v(self: "Self", value: "float") -> None:
        self.wrapped.MeanContactPointV = float(value) if value is not None else 0.0

    @property
    def cast_to(self: "Self") -> "_Cast_ConicalManufacturingSMTControlParameters":
        """Cast to another type.

        Returns:
            _Cast_ConicalManufacturingSMTControlParameters
        """
        return _Cast_ConicalManufacturingSMTControlParameters(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1273 import (
        BeamSectionType,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1274 import (
        ContactPairConstrainedSurfaceType,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1275 import (
        ContactPairReferenceSurfaceType,
    )
    from mastapy._private.fe_tools.vis_tools_global.vis_tools_global_enums._1276 import (
        ElementPropertiesShellWallType,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1273": [
            "BeamSectionType"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1274": [
            "ContactPairConstrainedSurfaceType"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1275": [
            "ContactPairReferenceSurfaceType"
        ],
        "_private.fe_tools.vis_tools_global.vis_tools_global_enums._1276": [
            "ElementPropertiesShellWallType"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BeamSectionType",
    "ContactPairConstrainedSurfaceType",
    "ContactPairReferenceSurfaceType",
    "ElementPropertiesShellWallType",
)



"""ShaftSettingsItem"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import (
    constructor,
    conversion,
    enum_with_selected_value_runtime,
    utility,
)
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal.implicit import enum_with_selected_value
from mastapy._private.shafts import _34
from mastapy._private.utility.databases import _1879
from mastapy._private._internal.cast_exception import CastException

_DATABASE_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Databases", "DatabaseWithSelectedItem"
)
_SHAFT_SETTINGS_ITEM = python_net_import("SMT.MastaAPI.Shafts", "ShaftSettingsItem")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.shafts import _13

    Self = TypeVar("Self", bound="ShaftSettingsItem")
    CastSelf = TypeVar("CastSelf", bound="ShaftSettingsItem._Cast_ShaftSettingsItem")


__docformat__ = "restructuredtext en"
__all__ = ("ShaftSettingsItem",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ShaftSettingsItem:
    """Special nested class for casting ShaftSettingsItem to subclasses."""

    __parent__: "ShaftSettingsItem"

    @property
    def named_database_item(self: "CastSelf") -> "_1879.NamedDatabaseItem":
        return self.__parent__._cast(_1879.NamedDatabaseItem)

    @property
    def shaft_settings_item(self: "CastSelf") -> "ShaftSettingsItem":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ShaftSettingsItem(_1879.NamedDatabaseItem):
    """ShaftSettingsItem

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SHAFT_SETTINGS_ITEM

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def create_new_assembly_by_default_when_adding_part_via_dxf(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.CreateNewAssemblyByDefaultWhenAddingPartViaDXF

        if temp is None:
            return False

        return temp

    @create_new_assembly_by_default_when_adding_part_via_dxf.setter
    @enforce_parameter_types
    def create_new_assembly_by_default_when_adding_part_via_dxf(
        self: "Self", value: "bool"
    ) -> None:
        self.wrapped.CreateNewAssemblyByDefaultWhenAddingPartViaDXF = (
            bool(value) if value is not None else False
        )

    @property
    def material_database(self: "Self") -> "str":
        """str"""
        temp = self.wrapped.MaterialDatabase.SelectedItemName

        if temp is None:
            return ""

        return temp

    @material_database.setter
    @enforce_parameter_types
    def material_database(self: "Self", value: "str") -> None:
        self.wrapped.MaterialDatabase.SetSelectedItem(
            str(value) if value is not None else ""
        )

    @property
    def reliability_factor(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ReliabilityFactor

        if temp is None:
            return 0.0

        return temp

    @reliability_factor.setter
    @enforce_parameter_types
    def reliability_factor(self: "Self", value: "float") -> None:
        self.wrapped.ReliabilityFactor = float(value) if value is not None else 0.0

    @property
    def required_shaft_reliability(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RequiredShaftReliability

        if temp is None:
            return 0.0

        return temp

    @required_shaft_reliability.setter
    @enforce_parameter_types
    def required_shaft_reliability(self: "Self", value: "float") -> None:
        self.wrapped.RequiredShaftReliability = (
            float(value) if value is not None else 0.0
        )

    @property
    def shaft_rating_method(self: "Self") -> "_34.ShaftRatingMethod":
        """mastapy._private.shafts.ShaftRatingMethod

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaftRatingMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.Shafts.ShaftRatingMethod")

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.shafts._34", "ShaftRatingMethod"
        )(value)

    @property
    def shaft_rating_method_selector(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ShaftRatingMethod":
        """EnumWithSelectedValue[mastapy._private.shafts.ShaftRatingMethod]"""
        temp = self.wrapped.ShaftRatingMethodSelector

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_ShaftRatingMethod.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @shaft_rating_method_selector.setter
    @enforce_parameter_types
    def shaft_rating_method_selector(
        self: "Self", value: "_34.ShaftRatingMethod"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_ShaftRatingMethod.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.ShaftRatingMethodSelector = value

    @property
    def version_of_miners_rule(self: "Self") -> "_13.FkmVersionOfMinersRule":
        """mastapy._private.shafts.FkmVersionOfMinersRule"""
        temp = self.wrapped.VersionOfMinersRule

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Shafts.FkmVersionOfMinersRule"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.shafts._13", "FkmVersionOfMinersRule"
        )(value)

    @version_of_miners_rule.setter
    @enforce_parameter_types
    def version_of_miners_rule(
        self: "Self", value: "_13.FkmVersionOfMinersRule"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Shafts.FkmVersionOfMinersRule"
        )
        self.wrapped.VersionOfMinersRule = value

    @property
    def cast_to(self: "Self") -> "_Cast_ShaftSettingsItem":
        """Cast to another type.

        Returns:
            _Cast_ShaftSettingsItem
        """
        return _Cast_ShaftSettingsItem(self)



"""PointLoad"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.implicit import overridable
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._math.vector_2d import Vector2D
from mastapy._private.system_model.part_model import _2535
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_POINT_LOAD = python_net_import("SMT.MastaAPI.SystemModel.PartModel", "PointLoad")

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, TypeVar

    from mastapy._private.system_model.part_model import _2520, _2498, _2524
    from mastapy._private.system_model import _2256

    Self = TypeVar("Self", bound="PointLoad")
    CastSelf = TypeVar("CastSelf", bound="PointLoad._Cast_PointLoad")


__docformat__ = "restructuredtext en"
__all__ = ("PointLoad",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PointLoad:
    """Special nested class for casting PointLoad to subclasses."""

    __parent__: "PointLoad"

    @property
    def virtual_component(self: "CastSelf") -> "_2535.VirtualComponent":
        return self.__parent__._cast(_2535.VirtualComponent)

    @property
    def mountable_component(self: "CastSelf") -> "_2520.MountableComponent":
        from mastapy._private.system_model.part_model import _2520

        return self.__parent__._cast(_2520.MountableComponent)

    @property
    def component(self: "CastSelf") -> "_2498.Component":
        from mastapy._private.system_model.part_model import _2498

        return self.__parent__._cast(_2498.Component)

    @property
    def part(self: "CastSelf") -> "_2524.Part":
        from mastapy._private.system_model.part_model import _2524

        return self.__parent__._cast(_2524.Part)

    @property
    def design_entity(self: "CastSelf") -> "_2256.DesignEntity":
        from mastapy._private.system_model import _2256

        return self.__parent__._cast(_2256.DesignEntity)

    @property
    def point_load(self: "CastSelf") -> "PointLoad":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class PointLoad(_2535.VirtualComponent):
    """PointLoad

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _POINT_LOAD

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def drawing_radius(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.DrawingRadius

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @drawing_radius.setter
    @enforce_parameter_types
    def drawing_radius(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.DrawingRadius = value

    @property
    def offset(self: "Self") -> "Vector2D":
        """Vector2D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Offset

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector2d(temp)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def set_offset(self: "Self", radius: "float", angle: "float") -> None:
        """Method does not return.

        Args:
            radius (float)
            angle (float)
        """
        radius = float(radius)
        angle = float(angle)
        self.wrapped.SetOffset(radius if radius else 0.0, angle if angle else 0.0)

    @property
    def cast_to(self: "Self") -> "_Cast_PointLoad":
        """Cast to another type.

        Returns:
            _Cast_PointLoad
        """
        return _Cast_PointLoad(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.electric_machines.load_cases_and_analyses._1392 import (
        BasicDynamicForceLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1393 import (
        DynamicForceAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1394 import (
        DynamicForceLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1395 import (
        DynamicForcesOperatingPoint,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1396 import (
        EfficiencyMapAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1397 import (
        EfficiencyMapLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1398 import (
        ElectricMachineAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1399 import (
        ElectricMachineBasicMechanicalLossSettings,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1400 import (
        ElectricMachineControlStrategy,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1401 import (
        ElectricMachineEfficiencyMapSettings,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1402 import (
        ElectricMachineFEAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1403 import (
        ElectricMachineFEMechanicalAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1404 import (
        ElectricMachineLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1405 import (
        ElectricMachineLoadCaseBase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1406 import (
        ElectricMachineLoadCaseGroup,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1407 import (
        ElectricMachineMechanicalLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1408 import (
        EndWindingInductanceMethod,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1409 import (
        LeadingOrLagging,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1410 import (
        LoadCaseType,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1411 import (
        LoadCaseTypeSelector,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1412 import (
        MotoringOrGenerating,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1413 import (
        NonLinearDQModelMultipleOperatingPointsLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1414 import (
        NumberOfStepsPerOperatingPointSpecificationMethod,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1415 import (
        OperatingPointsSpecificationMethod,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1416 import (
        SingleOperatingPointAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1417 import (
        SlotDetailForAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1418 import (
        SpecifyTorqueOrCurrent,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1419 import (
        SpeedPointsDistribution,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1420 import (
        SpeedTorqueCurveAnalysis,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1421 import (
        SpeedTorqueCurveLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1422 import (
        SpeedTorqueLoadCase,
    )
    from mastapy._private.electric_machines.load_cases_and_analyses._1423 import (
        Temperatures,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.electric_machines.load_cases_and_analyses._1392": [
            "BasicDynamicForceLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1393": [
            "DynamicForceAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1394": [
            "DynamicForceLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1395": [
            "DynamicForcesOperatingPoint"
        ],
        "_private.electric_machines.load_cases_and_analyses._1396": [
            "EfficiencyMapAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1397": [
            "EfficiencyMapLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1398": [
            "ElectricMachineAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1399": [
            "ElectricMachineBasicMechanicalLossSettings"
        ],
        "_private.electric_machines.load_cases_and_analyses._1400": [
            "ElectricMachineControlStrategy"
        ],
        "_private.electric_machines.load_cases_and_analyses._1401": [
            "ElectricMachineEfficiencyMapSettings"
        ],
        "_private.electric_machines.load_cases_and_analyses._1402": [
            "ElectricMachineFEAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1403": [
            "ElectricMachineFEMechanicalAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1404": [
            "ElectricMachineLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1405": [
            "ElectricMachineLoadCaseBase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1406": [
            "ElectricMachineLoadCaseGroup"
        ],
        "_private.electric_machines.load_cases_and_analyses._1407": [
            "ElectricMachineMechanicalLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1408": [
            "EndWindingInductanceMethod"
        ],
        "_private.electric_machines.load_cases_and_analyses._1409": [
            "LeadingOrLagging"
        ],
        "_private.electric_machines.load_cases_and_analyses._1410": ["LoadCaseType"],
        "_private.electric_machines.load_cases_and_analyses._1411": [
            "LoadCaseTypeSelector"
        ],
        "_private.electric_machines.load_cases_and_analyses._1412": [
            "MotoringOrGenerating"
        ],
        "_private.electric_machines.load_cases_and_analyses._1413": [
            "NonLinearDQModelMultipleOperatingPointsLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1414": [
            "NumberOfStepsPerOperatingPointSpecificationMethod"
        ],
        "_private.electric_machines.load_cases_and_analyses._1415": [
            "OperatingPointsSpecificationMethod"
        ],
        "_private.electric_machines.load_cases_and_analyses._1416": [
            "SingleOperatingPointAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1417": [
            "SlotDetailForAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1418": [
            "SpecifyTorqueOrCurrent"
        ],
        "_private.electric_machines.load_cases_and_analyses._1419": [
            "SpeedPointsDistribution"
        ],
        "_private.electric_machines.load_cases_and_analyses._1420": [
            "SpeedTorqueCurveAnalysis"
        ],
        "_private.electric_machines.load_cases_and_analyses._1421": [
            "SpeedTorqueCurveLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1422": [
            "SpeedTorqueLoadCase"
        ],
        "_private.electric_machines.load_cases_and_analyses._1423": ["Temperatures"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BasicDynamicForceLoadCase",
    "DynamicForceAnalysis",
    "DynamicForceLoadCase",
    "DynamicForcesOperatingPoint",
    "EfficiencyMapAnalysis",
    "EfficiencyMapLoadCase",
    "ElectricMachineAnalysis",
    "ElectricMachineBasicMechanicalLossSettings",
    "ElectricMachineControlStrategy",
    "ElectricMachineEfficiencyMapSettings",
    "ElectricMachineFEAnalysis",
    "ElectricMachineFEMechanicalAnalysis",
    "ElectricMachineLoadCase",
    "ElectricMachineLoadCaseBase",
    "ElectricMachineLoadCaseGroup",
    "ElectricMachineMechanicalLoadCase",
    "EndWindingInductanceMethod",
    "LeadingOrLagging",
    "LoadCaseType",
    "LoadCaseTypeSelector",
    "MotoringOrGenerating",
    "NonLinearDQModelMultipleOperatingPointsLoadCase",
    "NumberOfStepsPerOperatingPointSpecificationMethod",
    "OperatingPointsSpecificationMethod",
    "SingleOperatingPointAnalysis",
    "SlotDetailForAnalysis",
    "SpecifyTorqueOrCurrent",
    "SpeedPointsDistribution",
    "SpeedTorqueCurveAnalysis",
    "SpeedTorqueCurveLoadCase",
    "SpeedTorqueLoadCase",
    "Temperatures",
)



"""HarmonicLoadDataExcelImport"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item
from mastapy._private.utility.units_and_measurements import _1657
from mastapy._private.system_model.analyses_and_results.static_loads import _7048, _7025
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_HARMONIC_LOAD_DATA_EXCEL_IMPORT = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads",
    "HarmonicLoadDataExcelImport",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.analyses_and_results.static_loads import _7074

    Self = TypeVar("Self", bound="HarmonicLoadDataExcelImport")
    CastSelf = TypeVar(
        "CastSelf",
        bound="HarmonicLoadDataExcelImport._Cast_HarmonicLoadDataExcelImport",
    )


__docformat__ = "restructuredtext en"
__all__ = ("HarmonicLoadDataExcelImport",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_HarmonicLoadDataExcelImport:
    """Special nested class for casting HarmonicLoadDataExcelImport to subclasses."""

    __parent__: "HarmonicLoadDataExcelImport"

    @property
    def harmonic_load_data_import_base(
        self: "CastSelf",
    ) -> "_7048.HarmonicLoadDataImportBase":
        return self.__parent__._cast(_7048.HarmonicLoadDataImportBase)

    @property
    def harmonic_load_data_excel_import(
        self: "CastSelf",
    ) -> "HarmonicLoadDataExcelImport":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class HarmonicLoadDataExcelImport(
    _7048.HarmonicLoadDataImportBase[
        _7025.ElectricMachineHarmonicLoadExcelImportOptions
    ]
):
    """HarmonicLoadDataExcelImport

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _HARMONIC_LOAD_DATA_EXCEL_IMPORT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def column_index_of_first_data_point(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.ColumnIndexOfFirstDataPoint

        if temp is None:
            return 0

        return temp

    @column_index_of_first_data_point.setter
    @enforce_parameter_types
    def column_index_of_first_data_point(self: "Self", value: "int") -> None:
        self.wrapped.ColumnIndexOfFirstDataPoint = (
            int(value) if value is not None else 0
        )

    @property
    def column_index_of_first_speed_point(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.ColumnIndexOfFirstSpeedPoint

        if temp is None:
            return 0

        return temp

    @column_index_of_first_speed_point.setter
    @enforce_parameter_types
    def column_index_of_first_speed_point(self: "Self", value: "int") -> None:
        self.wrapped.ColumnIndexOfFirstSpeedPoint = (
            int(value) if value is not None else 0
        )

    @property
    def excitation_order_as_rotational_order_of_shaft(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ExcitationOrderAsRotationalOrderOfShaft

        if temp is None:
            return 0.0

        return temp

    @excitation_order_as_rotational_order_of_shaft.setter
    @enforce_parameter_types
    def excitation_order_as_rotational_order_of_shaft(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.ExcitationOrderAsRotationalOrderOfShaft = (
            float(value) if value is not None else 0.0
        )

    @property
    def number_of_speeds(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.NumberOfSpeeds

        if temp is None:
            return 0

        return temp

    @number_of_speeds.setter
    @enforce_parameter_types
    def number_of_speeds(self: "Self", value: "int") -> None:
        self.wrapped.NumberOfSpeeds = int(value) if value is not None else 0

    @property
    def read_speeds_from_excel_sheet(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.ReadSpeedsFromExcelSheet

        if temp is None:
            return False

        return temp

    @read_speeds_from_excel_sheet.setter
    @enforce_parameter_types
    def read_speeds_from_excel_sheet(self: "Self", value: "bool") -> None:
        self.wrapped.ReadSpeedsFromExcelSheet = (
            bool(value) if value is not None else False
        )

    @property
    def row_index_of_first_data_point(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.RowIndexOfFirstDataPoint

        if temp is None:
            return 0

        return temp

    @row_index_of_first_data_point.setter
    @enforce_parameter_types
    def row_index_of_first_data_point(self: "Self", value: "int") -> None:
        self.wrapped.RowIndexOfFirstDataPoint = int(value) if value is not None else 0

    @property
    def row_index_of_first_speed_point(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.RowIndexOfFirstSpeedPoint

        if temp is None:
            return 0

        return temp

    @row_index_of_first_speed_point.setter
    @enforce_parameter_types
    def row_index_of_first_speed_point(self: "Self", value: "int") -> None:
        self.wrapped.RowIndexOfFirstSpeedPoint = int(value) if value is not None else 0

    @property
    def row_index_of_last_data_point(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.RowIndexOfLastDataPoint

        if temp is None:
            return 0

        return temp

    @row_index_of_last_data_point.setter
    @enforce_parameter_types
    def row_index_of_last_data_point(self: "Self", value: "int") -> None:
        self.wrapped.RowIndexOfLastDataPoint = int(value) if value is not None else 0

    @property
    def sheet_for_first_set_of_data(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_str":
        """ListWithSelectedItem[str]"""
        temp = self.wrapped.SheetForFirstSetOfData

        if temp is None:
            return ""

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_str",
        )(temp)

    @sheet_for_first_set_of_data.setter
    @enforce_parameter_types
    def sheet_for_first_set_of_data(self: "Self", value: "str") -> None:
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else ""
        )
        self.wrapped.SheetForFirstSetOfData = value

    @property
    def sheet_with_speed_data(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_str":
        """ListWithSelectedItem[str]"""
        temp = self.wrapped.SheetWithSpeedData

        if temp is None:
            return ""

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_str",
        )(temp)

    @sheet_with_speed_data.setter
    @enforce_parameter_types
    def sheet_with_speed_data(self: "Self", value: "str") -> None:
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else ""
        )
        self.wrapped.SheetWithSpeedData = value

    @property
    def speed_units(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_Unit":
        """ListWithSelectedItem[mastapy._private.utility.units_and_measurements.Unit]"""
        temp = self.wrapped.SpeedUnits

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_Unit",
        )(temp)

    @speed_units.setter
    @enforce_parameter_types
    def speed_units(self: "Self", value: "_1657.Unit") -> None:
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Unit.wrapper_type()
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.SpeedUnits = value

    @property
    def units_for_data_being_imported(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_Unit":
        """ListWithSelectedItem[mastapy._private.utility.units_and_measurements.Unit]"""
        temp = self.wrapped.UnitsForDataBeingImported

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_Unit",
        )(temp)

    @units_for_data_being_imported.setter
    @enforce_parameter_types
    def units_for_data_being_imported(self: "Self", value: "_1657.Unit") -> None:
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Unit.wrapper_type()
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.UnitsForDataBeingImported = value

    @property
    def speeds(self: "Self") -> "List[_7074.NamedSpeed]":
        """List[mastapy._private.system_model.analyses_and_results.static_loads.NamedSpeed]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Speeds

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    def select_excel_file(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.SelectExcelFile()

    @property
    def cast_to(self: "Self") -> "_Cast_HarmonicLoadDataExcelImport":
        """Cast to another type.

        Returns:
            _Cast_HarmonicLoadDataExcelImport
        """
        return _Cast_HarmonicLoadDataExcelImport(self)
